@@ -19,6 +19,7 @@ package ig
 
 import (
 	"fmt"
+	"io"
 	"os"
 	"os/exec"
 	"strings"
@@ -77,6 +78,20 @@ func WithValidateOutput(validateOutput func(t *testing.T, output string)) Option
 	}
 }
 
+// WithValidateStderrOutput used to compare the actual output with expected output.
+func WithValidateStderrOutput(validateOutput func(t *testing.T, output string)) Option {
+	return func(ig *runner) {
+		ig.ValidateStdErrOutput = validateOutput
+	}
+}
+
+// WithStdOutWriter sets a writes that receives the standard output of the command.
+func WithStdOutWriter(writer io.Writer) Option {
+	return func(ig *runner) {
+		ig.StdOutWriter = writer
+	}
+}
+
 // WithOutputMode sets the output mode
 func WithOutputMode(outputMode string) Option {
 	return func(ig *runner) {
